decode_call_inputs

Function decode_call_inputs 

pub fn decode_call_inputs<I: OffsetSizeTrait>(
    signature: &str,
    data: &GenericBinaryArray<I>,
    allow_decode_fail: bool,
) -> Result<RecordBatch>
Decodes given call input data in arrow format to arrow format. Output Arrow schema is auto generated based on the function signature. Handles any level of nesting with Lists/Structs.

Writes null for data rows that fail to decode if allow_decode_fail is set to true. Errors when a row fails to decode if allow_decode_fail is set to false.