pub fn decode_events(
signature: &str,
data: &RecordBatch,
allow_decode_fail: bool,
) -> Result<RecordBatch>Expand description
Decodes given event data in arrow format to arrow format. Output Arrow schema is auto generated based on the event signature. Handles any level of nesting with Lists/Structs.
Writes null for event data rows that fail to decode if allow_decode_fail is set to true.
Errors when a row fails to decode if allow_decode_fail is set to false.